///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "collision_entity.h"
#include "turtle_brains/graphics/implementation/tbi_renderer.h"

//--------------------------------------------------------------------------------------------------------------------//

CollisionEntity::CollisionEntity(const tbCore::tbString& entityType, const tbMath::Unstable::BoundingVolume& boundingVolume,
	const tbMath::Vector2& boundingOffset) :
	tbGame::Entity(entityType),
	mBoundingVolume(boundingVolume),
	mBoundingOffset(boundingOffset)
{
	SetBoundingVolume(boundingVolume, boundingOffset);
}

//--------------------------------------------------------------------------------------------------------------------//

CollisionEntity::~CollisionEntity(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::SetBoundingVolume(const tbMath::Unstable::BoundingVolume& boundingVolume, const tbMath::Vector2& boundingOffset)
{
	RemoveBoundingVolumes();

	mBoundingVolume = boundingVolume;
	mBoundingOffset = boundingOffset;

	if (true == mBoundingVolume.IsBox())
	{
		AddBoundingBox(mBoundingVolume.GetWidth(), mBoundingVolume.GetHeight(), mBoundingOffset);
	}
	else
	{
		AddBoundingCircle(mBoundingVolume.GetRadius(), mBoundingOffset);
	}
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::RenderBoundingVolume(const tbMath::Unstable::BoundingVolume& boundingVolume, const tbMath::Vector2& boundingOffset)
{
#ifdef developer_build
	return;

	if (boundingVolume.IsBox())
	{
		tbGraphics::Sprite box = tbGraphics::theSpriteManager.GetSpriteFromFile("data/blank_square.png");
		box.SetOrigin(tbGraphics::kAnchorCenter);
		box.SetScale(boundingVolume.GetWidth() / 64.0f, boundingVolume.GetHeight() / 64.0f);
		box.SetColor(tbGraphics::Color(0x80FF00FF));
		box.SetPosition(boundingOffset);
		box.SetDepth(1.0f);
		box.Render();
	}
	else
	{
		tbGraphics::Sprite circle = tbGraphics::theSpriteManager.GetSpriteFromFile("data/blank_circle.png");
		circle.SetOrigin(tbGraphics::kAnchorCenter);
		circle.SetScale(boundingVolume.GetRadius() / 64.0f, boundingVolume.GetRadius() / 64.0f);
		circle.SetColor(tbGraphics::Color(0x80FF00FF));
		circle.SetPosition(boundingOffset);
		circle.SetDepth(1.0f);
		circle.Render();
	}
#endif /* developer_build */
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::OnAdded(void)
{
	tbGame::Entity::OnAdded();
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::OnRemoved(void)
{
	tbGame::Entity::OnRemoved();
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::OnSimulate(void)
{
	tbGame::Entity::OnSimulate();
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::OnUpdate(const float deltaTime)
{
	tbGame::Entity::OnUpdate(deltaTime);
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::OnRender(void) const
{
	tbGame::Entity::OnRender();

	if (true == IsCollidable())
	{
		RenderBoundingVolume(GetBoundingVolume(), GetPosition() + GetBoundingOffset());
	}
}

//--------------------------------------------------------------------------------------------------------------------//

void CollisionEntity::OnCollideWith(tbGame::Entity& otherEntity)
{
	tbGame::Entity::OnCollideWith(otherEntity);
}

//--------------------------------------------------------------------------------------------------------------------//
