///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#ifndef _LudumDare34_CollisionEntity_h_
#define _LudumDare34_CollisionEntity_h_

#include "ludumdare34.h"
#include "turtle_brains/math/unstable/tbu_bounding_volume.h"

class CollisionEntity : public tbGame::Entity
{
public:
	CollisionEntity(const tbCore::tbString& entityType, const tbMath::Unstable::BoundingVolume& boundingVolume,
		const tbMath::Vector2& boundingOffset = tbMath::Vector2::kZero);
	virtual ~CollisionEntity(void);

	void SetBoundingVolume(const tbMath::Unstable::BoundingVolume& boundingVolume, const tbMath::Vector2& boundingOffset = tbMath::Vector2::kZero);

	virtual const tbMath::Unstable::BoundingVolume& GetBoundingVolume(void) const { return mBoundingVolume; }
	virtual const tbMath::Vector2& GetBoundingOffset(void) const { return mBoundingOffset; }

	static void RenderBoundingVolume(const tbMath::Unstable::BoundingVolume& boundingVolume, const tbMath::Vector2& boundingOffset);

protected:
	virtual void OnAdded(void) override;
	virtual void OnRemoved(void) override;
	virtual void OnSimulate(void) override;
	virtual void OnUpdate(const float deltaTime) override;
	virtual void OnRender(void) const override;
	virtual void OnCollideWith(tbGame::Entity& otherEntity) override;

private:
	tbMath::Unstable::BoundingVolume mBoundingVolume;
	tbMath::Vector2 mBoundingOffset;
};

#endif /* _LudumDare34_CollisionEntity_h_ */
