///
/// @file
/// @details This scene is the gameplay scene for the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "credits_scene.h"
#include "scene_manager.h"
#include "game_music.h"

#include "gif_export/gif_exporter.h"

//--------------------------------------------------------------------------------------------------------------------//

CreditsScene::CreditsScene(void) :
	mBackdropSprite(tbGraphics::theSpriteManager.GetSpriteFromFile("data/storm_bg.png"))
{
	AddGraphic(&mBackdropSprite);

	tbMath::Vector2 offset(10.0f, 100.0f);
	tbMath::Vector2 step(80.0f, 100.0f);

	//Technically this leaks memory...
	AddCreditable(offset, "blackbird_logo.png", "Team Lead / Programmer", "Tim \"BlackBird\" Beaudet");

	offset += step;
	AddCreditable(offset, "mmango_logo.png", "Music / Audio", "Jeremy \"mmango\" Bell");

	offset += step;
	AddCreditable(offset, "kvasirs_bottle_logo.png", "Lead Artist", "Daniel \"kvasir\" Akesson");

	offset += step;
	AddCreditable(offset, "toms_logo.png", "Additional Artist", "Toms Stals");

	offset += step;
	AddCreditable(offset, "olligobber_logo.png", "Level Design", "Oliver \"olligobber\"");
}

//--------------------------------------------------------------------------------------------------------------------//

CreditsScene::~CreditsScene(void)
{
}

void CreditsScene::AddCreditable(const tbMath::Vector2& offset, const tbCore::tbString& logoFile, const tbCore::tbString& title, const tbCore::tbString& name)
{
	const tbMath::Vector2 screenCenter(640.0f, 360.0f);

	tbGraphics::Sprite* logo = new tbGraphics::Sprite(tbGraphics::theSpriteManager.GetSpriteFromFile("data/credit_logos/" + logoFile));
	logo->SetOrigin(tbGraphics::kAnchorTopLeft);
	logo->SetScale(0.28f);
	logo->SetPosition(screenCenter.x + offset.x - 128.0f - 256.0f, offset.y);
	AddGraphic(logo);

	tbGraphics::Text* titleText = new tbGraphics::Text(title, 45.0f);
	titleText->SetPosition(screenCenter.x + offset.x - 290.0f, (offset.y));
	AddGraphic(titleText);

	tbGraphics::Text* nameText = new tbGraphics::Text(name, 34.0f);
	nameText->SetPosition(screenCenter.x + offset.x - 290.0f, offset.y + (256.0f * 0.28f) - (nameText->GetHeight()));
	AddGraphic(nameText);
}

//--------------------------------------------------------------------------------------------------------------------//

void CreditsScene::OnSimulate(void)
{
	FadingScene::OnSimulate();
}

//--------------------------------------------------------------------------------------------------------------------//

void CreditsScene::OnUpdate(const float deltaTime)
{
	FadingScene::OnUpdate(deltaTime);

	if (kBlackScreen == GetFadeState())
	{
		theSceneManager->ChangeToScene(kTitleScene);
	}

	if (true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyEscape))
	{	//This should be the very last check to happen as game ends immediately.
		FadeToBlack();
		//theSceneManager->QuitGame();
	}
}

//--------------------------------------------------------------------------------------------------------------------//

void CreditsScene::OnRender(void) const
{
	FadingScene::OnRender();
}

//--------------------------------------------------------------------------------------------------------------------//

void CreditsScene::OnOpen(void)
{
	GameMusic::SetMusicTrack(GameMusic::kCreditsTrack);
	FadingScene::OnOpen();
}

//--------------------------------------------------------------------------------------------------------------------//

void CreditsScene::OnClose(void)
{
	FadingScene::OnClose();
}

//--------------------------------------------------------------------------------------------------------------------//
