///
/// @file
/// @details This scene is the gameplay scene for the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "title_scene.h"
#include "scene_manager.h"
#include "game_music.h"

#include "gif_export/gif_exporter.h"

const tbGame::GameTimer kMaximumFadeTime(1000);

//--------------------------------------------------------------------------------------------------------------------//

FadingScene::FadingScene(void) :
	mBlackScreenSprite(tbGraphics::theSpriteManager.GetSpriteFromFile("data/blank_square.png")),
	mCurrentState(kFadeToGame),
	mStateTimer(0)
{
	mBlackScreenSprite.SetOrigin(tbGraphics::kAnchorCenter);
	mBlackScreenSprite.SetScale(100.0f, 100.0f);
	mBlackScreenSprite.SetColor(tbGraphics::Color::kBlack);
	mBlackScreenSprite.SetDepth(1.0f);
	mBlackScreenSprite.SetVisible(true);
//	AddGraphic(&mBlackScreenSprite);	
}

//--------------------------------------------------------------------------------------------------------------------//

FadingScene::~FadingScene(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::FadeToBlack(void)
{
	ChangeFadeState(kFadeToBlack);
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::FadeToGame(void)
{
	ChangeFadeState(kFadeToGame);
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::OnSimulate(void)
{
	tbGame::GameScene::OnSimulate();

	mStateTimer.IncrementStep();
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::OnUpdate(const float deltaTime)
{
	tbGame::GameScene::OnUpdate(deltaTime);
	TurtleBrains::Unstable::GifPerformCapture(deltaTime, tbApplication::tbKeyG);

	GameMusic::UpdateMusicTracks();

	if (kFadeToBlack == mCurrentState && mStateTimer.GetRemainingTime() > kMaximumFadeTime.GetRemainingTime())
	{
		ChangeFadeState(kBlackScreen);
	}

	if (kFadeToGame == mCurrentState && mStateTimer.GetRemainingTime() > kMaximumFadeTime.GetRemainingTime())
	{
		ChangeFadeState(kGameScreen);
	}
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::OnRender(void) const
{
	if (kFadeToBlack == mCurrentState)
	{
		float tween = mStateTimer.GetPercentageOf(kMaximumFadeTime);
		tbGraphics::Color color;
		color.SetColor(tween, tbGraphics::Color(0x00000000), tbGraphics::Color(0xFF000000));
		mBlackScreenSprite.SetColor(color);
		mBlackScreenSprite.SetVisible(true);
	}
	else if (kFadeToGame == mCurrentState)
	{
		float tween = mStateTimer.GetPercentageOf(kMaximumFadeTime);
		tbGraphics::Color color;
		color.SetColor(tween, tbGraphics::Color(0xFF000000), tbGraphics::Color(0x00000000));
		mBlackScreenSprite.SetColor(color);
		mBlackScreenSprite.SetVisible(true);
	}
	else if (kBlackScreen == mCurrentState)
	{
		mBlackScreenSprite.SetColor(tbGraphics::Color(0xFF000000));
		mBlackScreenSprite.SetVisible(true);
	}
	else
	{
		mBlackScreenSprite.SetVisible(false);
	}

	tbGame::GameScene::OnRender();

	mBlackScreenSprite.Render();
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::OnOpen(void)
{
	tbGame::GameScene::OnOpen();

	mCurrentState = kFadeToGame;
	mStateTimer  = tbGame::GameTimer(0);
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::OnClose(void)
{
	tbGame::GameScene::OnClose();
}

//--------------------------------------------------------------------------------------------------------------------//

void FadingScene::ChangeFadeState(const FadeState& fadeState)
{
	if (fadeState == mCurrentState)
	{
		return;
	}

	mCurrentState = fadeState;
	mStateTimer = tbGame::GameTimer(0);

	if (kFadeToBlack == mCurrentState)
	{
		mBlackScreenSprite.SetColor(tbGraphics::Color(0x00000000));
		mBlackScreenSprite.SetVisible(true);
	}

	if (kGameScreen == mCurrentState)
	{
		mBlackScreenSprite.SetColor(tbGraphics::Color(0x00000000));
		mBlackScreenSprite.SetVisible(false);
	}
}

//--------------------------------------------------------------------------------------------------------------------//
