///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#ifndef _LudumDare34_FireEntity_h_
#define _LudumDare34_FireEntity_h_

#include "ludumdare34.h"
#include "collision_entity.h"

class FireEntity : public CollisionEntity
{
public:
	enum FireStage
	{
		kFireDebris,
		kFireSmoking,
		kFireEmbers,
		kFireBlazing,
	};

	FireEntity(const tbMath::Vector2& position, const FireStage& stage = kFireEmbers);
	virtual ~FireEntity(void);

	const FireStage& GetFireStage(void) const { return mFireStage; }
	void WaterOnFire(void);

protected:
	void OnTriggerFire(void);
	void ChangeFireLevelTo(const FireStage& fireStage);
	void NextFireStage(void);
	void SetFireStage(const FireStage& fireStage);

	virtual void OnAdded(void) override;
	virtual void OnRemoved(void) override;
	virtual void OnSimulate(void) override;
	virtual void OnUpdate(const float deltaTime) override;
	virtual void OnRender(void) const override;
	virtual void OnCollideWith(tbGame::Entity& otherEntity) override;

private:
	tbGraphics::Sprite mDebrisSprite;
	tbGraphics::AnimatedSprite mSprite;
	bool mHasTriggered;
	FireStage mFireStage;

	tbGame::GameTimer mFireResetHackTimer;
	tbGame::GameTimer mStageIncreaseTimer;
};

#endif /* _LudumDare34_FireEntity_h_ */
