///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "level_name_entity.h"

const tbGame::GameTimer kMaximumShowNameTime(4000);
const tbGame::GameTimer kMaximumFadeOutTime(2000);

//--------------------------------------------------------------------------------------------------------------------//

LevelNameEntity::LevelNameEntity(const tbCore::tbString& levelName) :
	tbGame::Entity("GoalEntity"),
	mLevelName(levelName),
	mBackdropSprite(tbGraphics::theSpriteManager.GetSpriteFromFile("data/name_frame.png")),
	mNameText(levelName, 40.0f, "data/ostrich-regular.ttf"),
	mDelayTimer(kMaximumShowNameTime),
	mFadeOutTimer(kMaximumFadeOutTime)
{
	SetPosition(1280.0f / 2.0f, 75.0f);
	SetDepth(0.95f);

	mBackdropSprite.SetOrigin(tbGraphics::kAnchorCenter);	
	AddGraphic(&mBackdropSprite);

	mNameText.SetPosition(-mNameText.GetWidth() / 2.0f, -(mNameText.GetHeight() / 2.0f) + 5.0f);
	mNameText.SetColor(tbGraphics::Color::kBlack);
	AddGraphic(&mNameText);
}

//--------------------------------------------------------------------------------------------------------------------//

LevelNameEntity::~LevelNameEntity(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void LevelNameEntity::OnSimulate(void)
{
	tbGame::Entity::OnSimulate();

	if (false == mDelayTimer.IsZero())
	{
		mDelayTimer.DecrementStep();
		return;
	}

	if (true == mFadeOutTimer.DecrementStep())
	{
		GetEntityManager()->RemoveEntity(this);
		mNameText.SetVisible(false);
		mBackdropSprite.SetVisible(false);
	}
	else
	{
		float tween = mFadeOutTimer.GetPercentageOf(kMaximumFadeOutTime);
		tbGraphics::Color color;
		color.SetColor(tween, tbGraphics::Color(0x00FFFFFF), tbGraphics::Color(0xFFFFFFFF));
		mBackdropSprite.SetColor(color);

		color.SetColor(tween, tbGraphics::Color(0x00000000), tbGraphics::Color(0xFF000000));
		mNameText.SetColor(color);
	}
}

//--------------------------------------------------------------------------------------------------------------------//
