///
/// @file
/// @details Entry point of the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "ludumdare34.h"
#include "scene_manager.h"
#include "game_music.h"

//--------------------------------------------------------------------------------------------------------------------//

int real_main(int argumentCount, const char* argumentValues[])
{
	tbGame::GameApplication gameApplication;
	gameApplication.SetWindowTitle(tb_string("Ascending Roots"));

	tbGraphics::theSpriteManager.LoadSpriteSheetFromFile("player_sheet", "data/character_sheet.json");
	tbGraphics::theSpriteManager.LoadSpriteSheetFromFile("fire_sheet", "data/fire_sheet.json");
	tbGraphics::theSpriteManager.LoadSpriteSheetFromFile("tree_sheet", "data/tree_sheet.json");
	tbGraphics::theSpriteManager.LoadSpriteSheetFromFile("gold_sheet", "data/gold.json");
	tbGraphics::theSpriteManager.LoadSpriteSheetFromFile("water_can_sheet", "data/water_can.json");

	tbAudio::theAudioManager.LoadEventTable("audio_events", "data/audio/audio_events.json");

	GameMusic::InitializeMusicTracks();

	SceneManager::CreateSceneManager(gameApplication);
	gameApplication.RunGame(SceneManager::GetScene(kTitleScene));
	//gameApplication.RunGame(SceneManager::GetScene(kGameplayScene));
	//gameApplication.RunGame(SceneManager::GetScene(kCreditsScene));
	SceneManager::DestroySceneManager();

	return 0;
}

//--------------------------------------------------------------------------------------------------------------------//

int main(const int argumentCount, const char* argumentValues[])
{
	tb_log_open("debug_log.txt", true);
	tb_log("Started Game: ludumdare34\n");

	int returnCode = tb_debug_project_entry_point_with(real_main, argumentCount, argumentValues);

	tb_log("Clean shutdown.\n");
	tb_log_close();
	return returnCode;
}

//--------------------------------------------------------------------------------------------------------------------//
