///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "pickup_entity.h"
#include "water_droplet_entity.h"

//--------------------------------------------------------------------------------------------------------------------//

PickupEntity::PickupEntity(const tbMath::Vector2& position, const bool isGoldenCan) :
	CollisionEntity("PickupEntity", tbMath::Unstable::BoundingVolume(16.0f), tbMath::Vector2(0.0f, 0.0f)),
	mSprite((isGoldenCan) ? tbGraphics::theSpriteManager.GetAnimatedSprite("gold_sheet", "gold_water_can") : tbGraphics::theSpriteManager.GetAnimatedSprite("water_can_sheet", "water_can")),
	mIsGoldenCan(isGoldenCan)
{
	if (true == mIsGoldenCan)
	{
		mSprite.PlayAnimation("idle", true, true, kAnimationFrameRate);
		mSprite.SetOrigin(tbGraphics::kAnchorBottomCenter);
		AddGraphic(&mSprite);
	}
	else
	{
		mSprite.PlayAnimation("idle", true, true, kAnimationFrameRate);
		mSprite.SetOrigin(tbGraphics::kAnchorCenter);
		AddGraphic(&mSprite);
	}
	
	SetPosition(position);
}

//--------------------------------------------------------------------------------------------------------------------//

PickupEntity::~PickupEntity(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void PickupEntity::OnCollected(void)
{
	if (false == IsGoldenCan())
	{
		GetEntityManager()->AddEntity(new WaterDropletEntity(GetPosition() + tbMath::Vector2(-32.0f, 0.0f), 1));
		GetEntityManager()->AddEntity(new WaterDropletEntity(GetPosition() + tbMath::Vector2(0.0f, 0.0f), 2));
		GetEntityManager()->AddEntity(new WaterDropletEntity(GetPosition() + tbMath::Vector2(32.0f, 0.0f), 3));

		GetEntityManager()->RemoveEntity(this);
	}
}

//--------------------------------------------------------------------------------------------------------------------//

void PickupEntity::OnCollideWith(tbGame::Entity& otherEntity)
{
	CollisionEntity::OnCollideWith(otherEntity);
}

//--------------------------------------------------------------------------------------------------------------------//
