///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#ifndef _LudumDare34_PlayerEntity_h_
#define _LudumDare34_PlayerEntity_h_

#include "ludumdare34.h"
#include "collision_entity.h"

class PlayerEntity : public CollisionEntity
{
public:
	PlayerEntity(const tbGame::TileSystem& tileSystem);
	virtual ~PlayerEntity(void);

	bool IsMoving(void) const;
	bool IsOnGround(void) const;
	bool IsClimbing(void) const;
	void ResetToStart(void);

	void OnBurnToDeath(void);
	void OnCollectWater(const int count);

protected:
	virtual void OnAdded(void) override;
	virtual void OnRemoved(void) override;
	virtual void OnSimulate(void) override;
	virtual void OnUpdate(const float deltaTime) override;
	virtual void OnRender(void) const override;
	virtual void OnCollideWith(tbGame::Entity& otherEntity) override;

	tbMath::Vector2 SimulateMovement(void);
	void SimulateUsingWater(void);
	void OnFallDeath(void);
	void OnSuicidalDeath(void);

private:
	const tbMath::Unstable::BoundingVolume GetWaterBoundingVolume(void) const;
	const tbMath::Vector2 GetWaterBoundingOffset(void) const;

	const tbGame::TileSystem& mTileSystem;
	tbGraphics::AnimatedSprite mSprite;

	tbMath::Vector2 mLastSafeHeight; //for fall distance / death, safe when on ground or climbing tree.

	bool mIsOnSlant;
	bool mHasWonLevel;
	bool mHasWonGame;
	bool mIsAlive;
	bool mIsOnTree;
	bool mIsFacingLeft;
	bool mIsMovingLeft;
	bool mIsMovingRight;
	bool mIsClimbingUp;
	bool mIsClimbingDown;
	bool mIsUsingWater;
	bool mIsUsingSeeds;

	enum ClimbMove
	{
		kClimbNone,
		kClimbDelay,
		kClimbUp,
		kClimbDown,
		kShimmyLeft,
		kShimmyRight,
	};

	tbMath::Vector2 mStartOfClimbMove;
	ClimbMove mClimbMove;
	tbGame::GameTimer mClimbMoveTimer;

	tbMath::Vector2 mPreviousPosition;

	tbGame::GameTimer mSeedsUseTimer;
	tbGame::GameTimer mWaterUseTimer;

	int mRemainingWater;
	int mRemainingSeeds;
	tbGame::GameTimer mDeathDelayResetTimer;
	tbGraphics::Sprite mWinningScreenFade;
};

#endif /* _LudumDare34_PlayerEntity_h_ */
