///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "slanted_entity.h"
#include "player_entity.h"

//--------------------------------------------------------------------------------------------------------------------//

SlantedEntity::SlantedEntity(const tbMath::Vector2& position, bool slantedUpRight) :
	CollisionEntity("SlantedEntity", tbMath::Unstable::BoundingVolume(30.0f, 32.0f), tbMath::Vector2(0.0f, -16.0f)),
	mSlantedUpRight(slantedUpRight)
{
	SetPosition(position);
}

//--------------------------------------------------------------------------------------------------------------------//

SlantedEntity::~SlantedEntity(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

float SlantedEntity::FindHeightAt(const float worldX) const
{
	const float minimumWorldY = GetPosition().y - 32.0f;
	const float maximumWorldY = GetPosition().y;	

	const float localX = worldX - GetPosition().x + 16.0f;

	if (true == mSlantedUpRight)
	{
		if (localX > 32.0f) { return minimumWorldY; }
		if (localX < 0.0f) { return maximumWorldY; }
		return tbMath::Interpolation::Linear(localX / 32.0f, maximumWorldY, minimumWorldY);
	}
	else
	{
		if (localX > 32.0f) { return maximumWorldY; }
		if (localX < 0.0f) { return minimumWorldY; }
		return tbMath::Interpolation::Linear(localX / 32.0f, minimumWorldY, maximumWorldY);
	}

	tb_error("This was unexpected!");
	return maximumWorldY;
}

//--------------------------------------------------------------------------------------------------------------------//

void SlantedEntity::OnCollideWith(tbGame::Entity& otherEntity)
{
	CollisionEntity::OnCollideWith(otherEntity);

	//if ("PlayerEntity" == otherEntity.GetEntityType())
	//{
	//	PlayerEntity* player = dynamic_cast<PlayerEntity*>(&otherEntity);
	//	tb_error_if(nullptr == player, "Expected player to be an object of type PlayerEntity");

	//	const float playerX(player->GetPosition().x);
	//	float heightAt = FindHeightAt(playerX);
	//	player->SetPosition(playerX, heightAt);
	//}
}

//--------------------------------------------------------------------------------------------------------------------//
