///
/// @file
/// @details This scene is the gameplay scene for the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "title_scene.h"
#include "scene_manager.h"
#include "game_music.h"

#include "gif_export/gif_exporter.h"

//--------------------------------------------------------------------------------------------------------------------//

TitleScene::TitleScene(void) :
	mBackdropSprite(tbGraphics::theSpriteManager.GetSpriteFromFile("data/backdrop_title.png")),
	mMusicDelay(250)
{
	AddGraphic(&mBackdropSprite);
}

//--------------------------------------------------------------------------------------------------------------------//

TitleScene::~TitleScene(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void TitleScene::OnSimulate(void)
{
	FadingScene::OnSimulate();
}

//--------------------------------------------------------------------------------------------------------------------//

void TitleScene::OnUpdate(const float deltaTime)
{
	FadingScene::OnUpdate(deltaTime);

	if (true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeySpace)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyA)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyS)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyW)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyD)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyJ)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyK)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyLeft)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyRight)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyUp)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyDown)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyX)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyZ)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbMouseLeft)
		|| true == tbApplication::Input::IsKeyReleased(tbApplication::tbMouseRight))
	{
		FadeToBlack();
	}

	if (kBlackScreen == GetFadeState())
	{
		theSceneManager->ChangeToScene(kGameplayScene);
	}

	if (true == tbApplication::Input::IsKeyReleased(tbApplication::tbKeyEscape))
	{	//This should be the very last check to happen as game ends immediately.
		theSceneManager->QuitGame();
	}
}

//--------------------------------------------------------------------------------------------------------------------//

void TitleScene::OnRender(void) const
{
	FadingScene::OnRender();
}

//--------------------------------------------------------------------------------------------------------------------//

void TitleScene::OnOpen(void)
{
	GameMusic::SetMusicTrack(GameMusic::kGameplayTrack);
	FadingScene::OnOpen();
}

//--------------------------------------------------------------------------------------------------------------------//

void TitleScene::OnClose(void)
{
	FadingScene::OnClose();
}

//--------------------------------------------------------------------------------------------------------------------//
