///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "tree_entity.h"

//--------------------------------------------------------------------------------------------------------------------//

TreeEntity::TreeEntity(const tbMath::Vector2& position, const GrowthStage& growthStage) :
	CollisionEntity("TreeEntity", tbMath::Unstable::BoundingVolume(28.0f, 64.0f), tbMath::Vector2(0.0f, -32.0f)),
	mSprite(tbGraphics::theSpriteManager.GetAnimatedSprite("tree_sheet", "tree")),
	mGrowthStage(growthStage)
{
	SetPosition(position);
	SetGrowthStage(growthStage, true);

	mSprite.SetPosition(0.0f, 2.0f);
	mSprite.SetOrigin(tbGraphics::kAnchorBottomCenter);	
	AddGraphic(&mSprite);
}

//--------------------------------------------------------------------------------------------------------------------//

TreeEntity::~TreeEntity(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::GrowBigger(void)
{
	if (kSeedling == mGrowthStage) { SetGrowthStage(kLittleTree); }
	else if (kLittleTree == mGrowthStage) { SetGrowthStage(kNormalTree); }
	else if (kNormalTree == mGrowthStage) { SetGrowthStage(kLargeTree); }

	tbAudio::theAudioManager.PlayEvent("audio_events", "tree_growth");
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::OnAdded(void)
{
	CollisionEntity::OnAdded();
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::OnRemoved(void)
{
	CollisionEntity::OnRemoved();
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::OnSimulate(void)
{
	CollisionEntity::OnSimulate();
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::OnUpdate(const float deltaTime)
{
	CollisionEntity::OnUpdate(deltaTime);
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::OnRender(void) const
{
	CollisionEntity::OnRender();
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::OnCollideWith(tbGame::Entity& otherEntity)
{
	CollisionEntity::OnCollideWith(otherEntity);
}

//--------------------------------------------------------------------------------------------------------------------//

void TreeEntity::SetGrowthStage(const GrowthStage& growthStage, bool immediate)
{
	mGrowthStage = growthStage;
	if (kSeedling == mGrowthStage)
	{
		SetBoundingVolume(tbMath::Unstable::BoundingVolume(28.0f, 16.0f), tbMath::Vector2(0.0f, 9.0f)); //in ground so can't climb yet.tom
		mSprite.PlayAnimation("grow_seedling", false, true, kAnimationFrameRate);
		if (true == immediate)
		{
			mSprite.PlayAnimation("grow_seedling", false, false, kAnimationFrameRate);
			mSprite.StopAnimation();
		}
	}
	else if (kLittleTree == mGrowthStage)
	{
		SetBoundingVolume(tbMath::Unstable::BoundingVolume(28.0f, 96.0f), tbMath::Vector2(0.0f, -48.0f));
		mSprite.PlayAnimation("grow_little", false, true, kAnimationFrameRate);
		if (true == immediate)
		{
			mSprite.PlayAnimation("grow_little", false, false, kAnimationFrameRate);
			mSprite.StopAnimation();
		}
	}
	else if (kNormalTree == mGrowthStage)
	{
		SetBoundingVolume(tbMath::Unstable::BoundingVolume(28.0f, 160.0f), tbMath::Vector2(0.0f, -80.0f));
		mSprite.PlayAnimation("grow_normal", false, true, kAnimationFrameRate);
		if (true == immediate)
		{
			mSprite.PlayAnimation("grow_normal", false, false, kAnimationFrameRate);
			mSprite.StopAnimation();
		}
	}
	else if (kLargeTree == mGrowthStage)
	{
		SetBoundingVolume(tbMath::Unstable::BoundingVolume(28.0f, 256.0f), tbMath::Vector2(0.0f, -128.0f));
		mSprite.PlayAnimation("grow_large", false, true, kAnimationFrameRate);
		if (true == immediate)
		{
			mSprite.PlayAnimation("grow_large", false, false, kAnimationFrameRate);
			mSprite.StopAnimation();
		}
	}
}

//--------------------------------------------------------------------------------------------------------------------//
