///
/// @file
/// @details An entity within the ludumdare34 project.
///
/// <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
///-----------------------------------------------------------------------------------------------------------------///

#include "water_droplet_entity.h"
#include "player_entity.h"

//--------------------------------------------------------------------------------------------------------------------//

class CollectWaterBehavior : public tbGame::EntityBehaviorInterface
{
public:
	CollectWaterBehavior(tbGame::EntityInterface& entity) :
		EntityBehaviorInterface(entity)
	{
	}

	virtual void OnSimulate(void)
	{
		std::list<tbGame::EntityInterface*> entities = mEntity.GetEntityManager()->GetEntitiesByType("PlayerEntity");
		tb_error_if(1 != entities.size(), "Expected there to be 1 player");

		PlayerEntity* player = dynamic_cast<PlayerEntity*>(entities.front());
		tb_error_if(nullptr == player, "Expected player to be a PlayerEntity object");
		player->OnCollectWater(1);
		tbAudio::theAudioManager.PlayEvent("audio_events", "collect_water_counter");

		mEntity.GetEntityManager()->RemoveEntity(&mEntity);
		mEntity.PopBehavior();
	}

private:
};


//--------------------------------------------------------------------------------------------------------------------//

WaterDropletEntity::WaterDropletEntity(const tbMath::Vector2& position, int delayNumber) :
	tbGame::Entity("WaterDropletEntity"),
	mSprite(tbGraphics::theSpriteManager.GetSpriteFromFile("data/water_icon.png")),
	mDelayTimer(delayNumber * 250)
{
	mSprite.SetOrigin(tbGraphics::kAnchorTopLeft);
	AddGraphic(&mSprite);
	SetPosition(position);

	PushBehavior(new CollectWaterBehavior(*this));
	PushBehavior(new tbGame::MoveToBehavior(*this, tbMath::Vector2(20.0f, 20.0f), 1500.0f));
	PushBehavior(new tbGame::DelayBehavior(*this, 0.1f * delayNumber));
}

//--------------------------------------------------------------------------------------------------------------------//

WaterDropletEntity::~WaterDropletEntity(void)
{
}

//--------------------------------------------------------------------------------------------------------------------//

void WaterDropletEntity::OnSimulate(void)
{
	tbGame::EntityInterface::OnSimulate();
}

//--------------------------------------------------------------------------------------------------------------------//
